# Generated by Django 2.1.9 on 2019-06-19 14:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("courses", "0003_auto_20190612_1743")]

    operations = [
        migrations.AlterField(
            model_name="person",
            name="first_name",
            field=models.CharField(
                blank=True, max_length=200, null=True, verbose_name="First name"
            ),
        ),
        migrations.AlterField(
            model_name="person",
            name="last_name",
            field=models.CharField(
                blank=True, max_length=200, null=True, verbose_name="Last name"
            ),
        ),
    ]
