(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[58076],{58076:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"Ọdúnǹí",1:"Àmọ́dún",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"Èṣín"},"year-short":{0:"Ọdún yìí",1:"Ọdún tó ńbọ̀",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"Ọdún tó kọjá"},"year-narrow":{0:"Ọdún yìí",1:"Ọdún tó ńbọ̀",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"Ọdún tó kọjá"},quarter:{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-short":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},month:{0:"oṣù yìí",1:"óṣù tó ń bọ̀,",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"óṣù tó kọjá"},"month-short":{0:"oṣù yìí",1:"óṣù tó ń bọ̀,",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"óṣù tó kọjá"},"month-narrow":{0:"oṣù yìí",1:"óṣù tó ń bọ̀,",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"óṣù tó kọjá"},week:{0:"ọ̀sẹ̀ yìí",1:"ọ́sẹ̀ tó ń bọ̀",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"ọ̀sẹ̀ tó kọjá"},"week-short":{0:"ọ̀sẹ̀ yìí",1:"ọ́sẹ̀ tó ń bọ̀",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"ọ̀sẹ̀ tó kọjá"},"week-narrow":{0:"ọ̀sẹ̀ yìí",1:"ọ́sẹ̀ tó ń bọ̀",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"ọ̀sẹ̀ tó kọjá"},day:{0:"Òní",1:"Ọ̀la",2:"òtúùnla",future:{other:"+{0} d"},past:{other:"-{0} d"},"-2":"íjẹta","-1":"Àná"},"day-short":{0:"Òní",1:"Ọ̀la",2:"òtúùnla",future:{other:"+{0} d"},past:{other:"-{0} d"},"-2":"íjẹta","-1":"Àná"},"day-narrow":{0:"Òní",1:"Ọ̀la",2:"òtúùnla",future:{other:"+{0} d"},past:{other:"-{0} d"},"-2":"íjẹta","-1":"Àná"},hour:{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-short":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-narrow":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},minute:{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-short":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-narrow":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},second:{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-short":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-narrow":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}}},locale:"yo"})}}]);
//# sourceMappingURL=58076.e894b2552334d7259027.index.js.map