(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[66933],{66933:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"tahun ini",1:"tahun depan",future:{other:"dalam {0} tahun"},past:{other:"{0} tahun lalu"},"-1":"tahun lalu"},"year-short":{0:"thn ini",1:"thn depan",future:{other:"dalam {0} thn"},past:{other:"{0} thn lalu"},"-1":"thn lepas"},"year-narrow":{0:"thn ini",1:"thn depan",future:{other:"dalam {0} thn"},past:{other:"{0} thn lalu"},"-1":"thn lepas"},quarter:{0:"suku tahun ini",1:"suku tahun seterusnya",future:{other:"dalam {0} suku tahun"},past:{other:"{0} suku tahun lalu"},"-1":"suku tahun lalu"},"quarter-short":{0:"suku ini",1:"suku seterusnya",future:{other:"dlm {0} suku thn"},past:{other:"{0} suku thn lalu"},"-1":"suku lepas"},"quarter-narrow":{0:"suku ini",1:"suku seterusnya",future:{other:"dlm {0} suku thn"},past:{other:"{0} suku thn lalu"},"-1":"suku lepas"},month:{0:"bulan ini",1:"bulan depan",future:{other:"dalam {0} bulan"},past:{other:"{0} bulan lalu"},"-1":"bulan lalu"},"month-short":{0:"bln ini",1:"bln depan",future:{other:"dlm {0} bln"},past:{other:"{0} bln lalu"},"-1":"bln lalu"},"month-narrow":{0:"bln ini",1:"bln depan",future:{other:"dlm {0} bln"},past:{other:"{0} bulan lalu"},"-1":"bln lalu"},week:{0:"minggu ini",1:"minggu depan",future:{other:"dalam {0} minggu"},past:{other:"{0} minggu lalu"},"-1":"minggu lalu"},"week-short":{0:"mgu ini",1:"mgu depan",future:{other:"dlm {0} mgu"},past:{other:"{0} mgu lalu"},"-1":"mgu lepas"},"week-narrow":{0:"mgu ini",1:"mgu depan",future:{other:"dlm {0} mgu"},past:{other:"{0} mgu lalu"},"-1":"mgu lepas"},day:{0:"hari ini",1:"esok",2:"lusa",future:{other:"dalam {0} hari"},past:{other:"{0} hari lalu"},"-2":"kelmarin","-1":"semalam"},"day-short":{0:"hari ini",1:"esok",2:"lusa",future:{other:"dlm {0} hari"},past:{other:"{0} hari lalu"},"-2":"kelmarin","-1":"semalam"},"day-narrow":{0:"hari ini",1:"esok",2:"lusa",future:{other:"dlm {0} hari"},past:{other:"{0} hari lalu"},"-2":"kelmarin","-1":"semlm"},hour:{0:"jam ini",future:{other:"dalam {0} jam"},past:{other:"{0} jam lalu"}},"hour-short":{0:"jam ini",future:{other:"dlm {0} jam"},past:{other:"{0} jam lalu"}},"hour-narrow":{0:"jam ini",future:{other:"dlm {0} jam"},past:{other:"{0} jam lalu"}},minute:{0:"pada minit ini",future:{other:"dalam {0} minit"},past:{other:"{0} minit lalu"}},"minute-short":{0:"pada minit ini",future:{other:"dlm {0} min"},past:{other:"{0} min lalu"}},"minute-narrow":{0:"pada minit ini",future:{other:"dlm {0} min"},past:{other:"{0} min lalu"}},second:{0:"sekarang",future:{other:"dalam {0} saat"},past:{other:"{0} saat lalu"}},"second-short":{0:"sekarang",future:{other:"dlm {0} saat"},past:{other:"{0} saat lalu"}},"second-narrow":{0:"sekarang",future:{other:"dlm {0} saat"},past:{other:"{0} saat lalu"}}},locale:"ms"})}}]);
//# sourceMappingURL=66933.e894b2552334d7259027.index.js.map