{% spaceless %}
{% if organizations %}
    <div class="organization-glimpse-list">
        {% for organization in organizations %}
            {% include "courses/cms/fragment_organization_glimpse.html" %}
        {% endfor %}
    </div>
{% endif %}
{% endspaceless %}
