{% extends "richie/base.html" %}
{% load cms_tags i18n static %}
{% get_current_language as LANGUAGE_CODE %}

{% block meta %}
  {{ block.super }}
  {% if CDN_DOMAIN %}
  <meta name="public-path" value="{{ CDN_DOMAIN }}" />
  {% endif %}
{% endblock meta %}

{% block head_title %}{% page_attribute "page_title" %}{% endblock head_title %}

{% block topbar_searchbar %}{% endblock topbar_searchbar %}


{% block subheader %}
<div class="subheader">
    {% block breadcrumbs %}
    {% include "menu/breadcrumbs.html" %}
    {% endblock breadcrumbs %}

    {% block subheader_content %}{% spaceless %}
        <div class="subheader__container">
            <div class="subheader__search">
                <h1 class="subheader__title">{{ current_page.get_title }}</h1>
                <div class="richie-react richie-react--search-suggest-field"></div>
            </div>
        </div>
    {% endspaceless %}{% endblock subheader_content %}
</div>
{% endblock subheader %}


{% block content %}
  <div class="search-template">
    <div class="search-template__content">
      {% with header_level=2 %}
        {% placeholder "content" %}
      {% endwith %}
      <div class="richie-react richie-react--search"></div>
    </div>
  </div>
{% endblock content %}
