{% load cms_tags %}{% spaceless %}

<div class="section-tiles">
    <div class="section-tiles__row">
        {% if instance.title %}
            <h{{ header_level|default:2 }} class="section-tiles__title">{{ instance.title }}</h{{ header_level|default:2 }}>
        {% endif %}
        <div class="section-tiles__items">
        {% for plugin in instance.child_plugin_instances %}
            {% with category_variant="glimpse" %}
                {% render_plugin plugin %}
            {% endwith %}
        {% endfor %}
        </div>
    </div>
</div>

{% endspaceless %}
