# Generated by Django 3.1.5 on 2021-01-19 13:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("courses", "0026_courserun_sync_mode")]

    operations = [
        migrations.AddField(
            model_name="personpluginmodel",
            name="bio",
            field=models.TextField(
                blank=True,
                default="",
                help_text=(
                    "Optional: provide a custom bio "
                    "(if you leave it empty, it will display the person's bio)."
                ),
                null=True,
                verbose_name="Custom bio",
            ),
        ),
        migrations.AlterField(
            model_name="course",
            name="code",
            field=models.CharField(
                blank=True,
                help_text="Unique reference for the course.",
                max_length=100,
                null=True,
                verbose_name="code",
            ),
        ),
    ]
