(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[87063],{87063:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"今年",1:"下年",future:{other:"{0} 年後"},past:{other:"{0} 年前"},"-1":"上年"},"year-short":{0:"今年",1:"下年",future:{other:"{0} 年後"},past:{other:"{0} 年前"},"-1":"上年"},"year-narrow":{0:"今年",1:"下年",future:{other:"{0}年後"},past:{other:"{0}年前"},"-1":"上年"},quarter:{0:"今季",1:"下一季",future:{other:"{0} 季後"},past:{other:"{0} 季前"},"-1":"上一季"},"quarter-short":{0:"今季",1:"下季",future:{other:"{0} 季後"},past:{other:"{0} 季前"},"-1":"上季"},"quarter-narrow":{0:"今季",1:"下季",future:{other:"+{0}Q"},past:{other:"-{0}Q"},"-1":"上季"},month:{0:"本月",1:"下個月",future:{other:"{0} 個月後"},past:{other:"{0} 個月前"},"-1":"上個月"},"month-short":{0:"本月",1:"下個月",future:{other:"{0} 個月後"},past:{other:"{0} 個月前"},"-1":"上個月"},"month-narrow":{0:"本月",1:"下個月",future:{other:"{0}個月後"},past:{other:"{0}個月前"},"-1":"上個月"},week:{0:"本星期",1:"下星期",future:{other:"{0} 星期後"},past:{other:"{0} 星期前"},"-1":"上星期"},"week-short":{0:"本星期",1:"下星期",future:{other:"{0} 星期後"},past:{other:"{0} 星期前"},"-1":"上星期"},"week-narrow":{0:"本星期",1:"下星期",future:{other:"{0}星期後"},past:{other:"{0}星期前"},"-1":"上星期"},day:{0:"今日",1:"明日",2:"後日",future:{other:"{0} 日後"},past:{other:"{0} 日前"},"-2":"前日","-1":"昨日"},"day-short":{0:"今日",1:"明日",2:"後日",future:{other:"{0} 日後"},past:{other:"{0} 日前"},"-2":"前日","-1":"昨日"},"day-narrow":{0:"今日",1:"明日",2:"後日",future:{other:"{0}日後"},past:{other:"{0}日前"},"-2":"前日","-1":"昨日"},hour:{0:"這個小時",future:{other:"{0} 小時後"},past:{other:"{0} 小時前"}},"hour-short":{0:"這個小時",future:{other:"{0} 小時後"},past:{other:"{0} 小時前"}},"hour-narrow":{0:"這個小時",future:{other:"{0}小時後"},past:{other:"{0}小時前"}},minute:{0:"這分鐘",future:{other:"{0} 分鐘後"},past:{other:"{0} 分鐘前"}},"minute-short":{0:"這分鐘",future:{other:"{0} 分鐘後"},past:{other:"{0} 分鐘前"}},"minute-narrow":{0:"這分鐘",future:{other:"{0}分後"},past:{other:"{0}分前"}},second:{0:"現在",future:{other:"{0} 秒後"},past:{other:"{0} 秒前"}},"second-short":{0:"現在",future:{other:"{0} 秒後"},past:{other:"{0} 秒前"}},"second-narrow":{0:"現在",future:{other:"{0}秒後"},past:{other:"{0}秒前"}}},locale:"zh-Hant-MO"})}}]);
//# sourceMappingURL=87063.e894b2552334d7259027.index.js.map