# Generated by Django 3.2.7 on 2021-09-30 11:10

from django.db import migrations

import djangocms_attributes_field.fields


class Migration(migrations.Migration):

    dependencies = [
        ("section", "0005_migrate_sectionlist_to_nesteditem"),
    ]

    operations = [
        migrations.AddField(
            model_name="section",
            name="attributes",
            field=djangocms_attributes_field.fields.AttributesField(
                blank=True, default=dict, verbose_name="Attributes"
            ),
        ),
    ]
