# Generated by Django 2.2.9 on 2020-01-02 15:07

import django.db.models.deletion
from django.db import migrations, models

import parler.models

import richie.apps.core.fields.multiselect


class Migration(migrations.Migration):

    dependencies = [("courses", "0011_deprecate_untranslated_licence_fields")]

    operations = [
        migrations.CreateModel(
            name="LicenceTranslation",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "language_code",
                    models.CharField(
                        db_index=True, max_length=15, verbose_name="Language"
                    ),
                ),
                ("name", models.CharField(max_length=200, verbose_name="name")),
                ("content", models.TextField(default="", verbose_name="content")),
                (
                    "master",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="translations",
                        to="courses.Licence",
                    ),
                ),
            ],
            options={
                "verbose_name": "Licence translation",
                "db_table": "richie_licence_translation",
                "unique_together": {("language_code", "master")},
            },
            bases=(parler.models.TranslatedFieldsModelMixin, models.Model),
        )
    ]
