(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[85189],{85189:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"бу йил",1:"кейинги йил",future:{one:"{0} йилдан сўнг",other:"{0} йилдан сўнг"},past:{one:"{0} йил аввал",other:"{0} йил аввал"},"-1":"ўтган йил"},"year-short":{0:"бу йил",1:"кейинги йил",future:{one:"{0} йилдан сўнг",other:"{0} йилдан сўнг"},past:{one:"{0} йил аввал",other:"{0} йил аввал"},"-1":"ўтган йил"},"year-narrow":{0:"бу йил",1:"кейинги йил",future:{one:"{0} йилдан сўнг",other:"{0} йилдан сўнг"},past:{one:"{0} йил аввал",other:"{0} йил аввал"},"-1":"ўтган йил"},quarter:{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-short":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},month:{0:"бу ой",1:"кейинги ой",future:{one:"{0} ойдан сўнг",other:"{0} ойдан сўнг"},past:{one:"{0} ой аввал",other:"{0} ой аввал"},"-1":"ўтган ой"},"month-short":{0:"бу ой",1:"кейинги ой",future:{one:"{0} ойдан сўнг",other:"{0} ойдан сўнг"},past:{one:"{0} ой аввал",other:"{0} ой аввал"},"-1":"ўтган ой"},"month-narrow":{0:"бу ой",1:"кейинги ой",future:{one:"{0} ойдан сўнг",other:"{0} ойдан сўнг"},past:{one:"{0} ой аввал",other:"{0} ой аввал"},"-1":"ўтган ой"},week:{0:"бу ҳафта",1:"кейинги ҳафта",future:{one:"{0} ҳафтадан сўнг",other:"{0} ҳафтадан сўнг"},past:{one:"{0} ҳафта олдин",other:"{0} ҳафта олдин"},"-1":"ўтган ҳафта"},"week-short":{0:"бу ҳафта",1:"кейинги ҳафта",future:{one:"{0} ҳафтадан сўнг",other:"{0} ҳафтадан сўнг"},past:{one:"{0} ҳафта олдин",other:"{0} ҳафта олдин"},"-1":"ўтган ҳафта"},"week-narrow":{0:"бу ҳафта",1:"кейинги ҳафта",future:{one:"{0} ҳафтадан сўнг",other:"{0} ҳафтадан сўнг"},past:{one:"{0} ҳафта олдин",other:"{0} ҳафта олдин"},"-1":"ўтган ҳафта"},day:{0:"бугун",1:"эртага",future:{one:"{0} кундан сўнг",other:"{0} кундан сўнг"},past:{one:"{0} кун олдин",other:"{0} кун олдин"},"-1":"кеча"},"day-short":{0:"бугун",1:"эртага",future:{one:"{0} кундан сўнг",other:"{0} кундан сўнг"},past:{one:"{0} кун олдин",other:"{0} кун олдин"},"-1":"кеча"},"day-narrow":{0:"бугун",1:"эртага",future:{one:"{0} кундан сўнг",other:"{0} кундан сўнг"},past:{one:"{0} кун олдин",other:"{0} кун олдин"},"-1":"кеча"},hour:{0:"this hour",future:{one:"{0} соатдан сўнг",other:"{0} соатдан сўнг"},past:{one:"{0} соат олдин",other:"{0} соат олдин"}},"hour-short":{0:"this hour",future:{one:"{0} соатдан сўнг",other:"{0} соатдан сўнг"},past:{one:"{0} соат олдин",other:"{0} соат олдин"}},"hour-narrow":{0:"this hour",future:{one:"{0} соатдан сўнг",other:"{0} соатдан сўнг"},past:{one:"{0} соат олдин",other:"{0} соат олдин"}},minute:{0:"this minute",future:{one:"{0} дақиқадан сўнг",other:"{0} дақиқадан сўнг"},past:{one:"{0} дақиқа олдин",other:"{0} дақиқа олдин"}},"minute-short":{0:"this minute",future:{one:"{0} дақиқадан сўнг",other:"{0} дақиқадан сўнг"},past:{one:"{0} дақиқа олдин",other:"{0} дақиқа олдин"}},"minute-narrow":{0:"this minute",future:{one:"{0} дақиқадан сўнг",other:"{0} дақиқадан сўнг"},past:{one:"{0} дақиқа олдин",other:"{0} дақиқа олдин"}},second:{0:"ҳозир",future:{one:"{0} сониядан сўнг",other:"{0} сониядан сўнг"},past:{one:"{0} сония олдин",other:"{0} сония олдин"}},"second-short":{0:"ҳозир",future:{one:"{0} сониядан сўнг",other:"{0} сониядан сўнг"},past:{one:"{0} сония олдин",other:"{0} сония олдин"}},"second-narrow":{0:"ҳозир",future:{one:"{0} сониядан сўнг",other:"{0} сониядан сўнг"},past:{one:"{0} сония олдин",other:"{0} сония олдин"}}},locale:"uz-Cyrl"})}}]);
//# sourceMappingURL=85189.e894b2552334d7259027.index.js.map