# Generated by Django 2.2.11 on 2020-03-09 22:43

from django.db import migrations, models

import richie.apps.core.fields.multiselect


class Migration(migrations.Migration):

    dependencies = [
        ("courses", "0013_migrate_data_translated_licence_fields"),
    ]

    operations = [
        migrations.AddField(
            model_name="blogpostpluginmodel",
            name="variant",
            field=models.CharField(
                blank=True,
                choices=[(None, "Default")],
                help_text="Optional glimpse variant for a custom look.",
                max_length=50,
                null=True,
                verbose_name="variant",
            ),
        ),
    ]
