(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[53494],{53494:function(){!function(){function e(){var e=Array.prototype.slice.call(arguments),n=document.createDocumentFragment();e.forEach((function(e){var t=e instanceof Node;n.appendChild(t?e:document.createTextNode(String(e)))})),this.appendChild(n)}[Element.prototype,Document.prototype,DocumentFragment.prototype].forEach((function(n){n.hasOwnProperty("append")||Object.defineProperty(n,"append",{configurable:!0,enumerable:!0,writable:!0,value:e})}))}()}}]);
//# sourceMappingURL=53494.e894b2552334d7259027.index.js.map