(self.webpackChunkrichie_education=self.webpackChunkrichie_education||[]).push([[72626],{72626:function(){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"ren",1:"dewen",future:{other:"fileek {0} at"},past:{other:"{0} at ci ginaaw"},"-1":"daaw"},"year-short":{0:"ren",1:"dewen",future:{other:"fileek {0} at"},past:{other:"{0} at ci ginaaw"},"-1":"daaw"},"year-narrow":{0:"ren",1:"dewen",future:{other:"fileek {0} at"},past:{other:"{0} at ci ginaaw"},"-1":"daaw"},quarter:{0:"trimestre bii",1:"trimestre biy ñëw",future:{other:"fileek {0} trimestre"},past:{other:"{0} trimestre ci ginaaw"},"-1":"trimestre bi weesu"},"quarter-short":{0:"trimestre bii",1:"trimestre biy ñëw",future:{other:"fileek {0} trim."},past:{other:"{0} trim. ci ginaaw"},"-1":"trimestre bi weesu"},"quarter-narrow":{0:"trimestre bii",1:"trimestre biy ñëw",future:{other:"fileek {0} trim."},past:{other:"{0} trim. ci ginaaw"},"-1":"trimestre bi weesu"},month:{0:"weer wii",1:"weer wiy ñëw",future:{other:"fileek {0} weer"},past:{other:"{0} weer ci ginaaw"},"-1":"weer wi weesu"},"month-short":{0:"we. wii",1:"we. wiy ñëw",future:{other:"fileek {0} we."},past:{other:"{0} we. ci ginaaw"},"-1":"we. wi wees"},"month-narrow":{0:"we. wii",1:"we. wiy ñëw",future:{other:"fileek {0} we."},past:{other:"{0} we. ci ginaaw"},"-1":"we. wi wees"},week:{0:"ayu-bis bii",1:"ayu-bis biy ñëw",future:{other:"fileek {0} ayi-bis"},past:{other:"{0} ayi-bis ci ginaaw"},"-1":"ayu-bis bi weesu"},"week-short":{0:"ayu-b bii",1:"ayu-b. ñëw",future:{other:"fileek {0} ayi-b."},past:{other:"{0} ayi-b. ci ginaaw"},"-1":"ayu-b bi wees"},"week-narrow":{0:"ayu-b bii",1:"ayu-b. ñëw",future:{other:"fileek {0} ayi-b."},past:{other:"{0} ayi-b. ci ginaaw"},"-1":"ayu-b bi wees"},day:{0:"tay",1:"suba",future:{other:"fileek {0} fan"},past:{other:"{0} fan ci ginaaw"},"-1":"démb"},"day-short":{0:"tay",1:"suba",future:{other:"fileek {0} fan"},past:{other:"{0} fan ci ginaaw"},"-1":"démb"},"day-narrow":{0:"tay",1:"suba",future:{other:"fileek {0} fan"},past:{other:"{0} fan ci ginaaw"},"-1":"démb"},hour:{0:"ci waxtu wii",future:{other:"fileek {0} waxtu"},past:{other:"{0} waxtu ci ginaaw"}},"hour-short":{0:"ci waxtu wii",future:{other:"fileek {0} wax."},past:{other:"{0} wax. ci ginaaw"}},"hour-narrow":{0:"ci waxtu wii",future:{other:"fileek {0} wax."},past:{other:"{0} wax. ci ginaaw"}},minute:{0:"ci simili bii",future:{other:"fileek {0} simili"},past:{other:"{0} simili ci ginaaw"}},"minute-short":{0:"ci simili bii",future:{other:"fileek {0} sim."},past:{other:"{0} sim. ci ginaaw"}},"minute-narrow":{0:"ci simili bii",future:{other:"fileek {0} sim."},past:{other:"{0} sim. ci ginaaw"}},second:{0:"leegi",future:{other:"fileek {0} saa"},past:{other:"{0} saa ci ginaaw"}},"second-short":{0:"leegi",future:{other:"fileek {0} saa"},past:{other:"{0} saa ci ginaaw"}},"second-narrow":{0:"leegi",future:{other:"fileek {0} saa"},past:{other:"{0} saa ci ginaaw"}}},locale:"wo"})}}]);
//# sourceMappingURL=72626.e894b2552334d7259027.index.js.map